@@ -1,8 +1,10 @@
 import gtk
-#import gnome
 import gtk.gdk
 from youamp import VERSION, IS_MAEMO
 
+if not IS_MAEMO:
+    import gnome
+
 GPLv3 = """YouAmp Music Player
 
 Copyright (C) 2008 Pavel Rojtberg
@@ -24,13 +26,16 @@ class AboutDialog(gtk.AboutDialog):
     def __init__(self, parent):
         gtk.AboutDialog.__init__(self)
         
-        #gtk.about_dialog_set_url_hook(self.on_url)
         self.set_transient_for(parent)
         
         self.set_name("YouAmp")
         self.set_version(VERSION)
-        #self.set_website("http://www.madman2k.net/article/108")
-        #self.set_website_label("YouAmp Website")
+        
+        if not IS_MAEMO:
+            gtk.about_dialog_set_url_hook(lambda caller, link: gnome.url_show(link))
+            self.set_website("http://www.rojtberg.net/workspace/youamp")
+            self.set_website_label("YouAmp Website")
+            
         self.set_copyright("Copyright (C) 2008 Pavel Rojtberg")
         self.set_license(GPLv3)
         self.set_authors(("Pavel Rojtberg",))
@@ -44,9 +49,6 @@ class AboutDialog(gtk.AboutDialog):
             
         self.connect("response", self._on_close)
         self.connect("delete-event", self._on_close)
-
-    #def on_url(self, caller, link):
-    #    gnome.url_show(link)
     
     def _on_close(self, caller, event):
         self.hide()
