@@ -98,8 +98,3 @@ class Controls(gtk.HBox):
             val = hvolume.get_level()/100
         
         self._config["volume"] = val
-        
-    def _update_pos(self):
-        self.pos.set_value(self._player.get_seek())
-        
-        return True
