@@ -87,8 +87,14 @@ class SearchView(gtk.VBox):
         self.pack_start(self._scroll)
 
         self.show_all() 
- 
-        # Restore View
+
+        self.restore()
+   
+        # browser callbacks
+        self._config.notify_add("search-artist", self._on_search_artist)
+        self._config.notify_add("search-album", self._on_search_album)
+    
+    def restore(self):
         if self._config["is-browser"]:
             a = self._config["search-artist"]
             txt = a if a != "" else _("All Artists")
@@ -105,12 +111,9 @@ class SearchView(gtk.VBox):
             self._browse_button.hide()
             self._artist.hide()
             self._album.hide()
-
-   
-        # browser callbacks
-        self._config.notify_add("search-artist", self._on_search_artist)
-        self._config.notify_add("search-album", self._on_search_album)
-
+        
+        self._playlist.restore()
+            
     def _on_shuffle_toggled(self, caller):
         self._config["shuffle"] = not self._config["shuffle"]
         self._player.playlist.shuffle(self._config["shuffle"])
@@ -246,14 +249,14 @@ class PlaylistView(gtk.TreeView):
             self.connect("drag-data-received", self._recieve_drag_data)
             self.enable_model_drag_source(gtk.gdk.BUTTON1_MASK, [("text/uri-list", 0, 0)], gtk.gdk.ACTION_COPY)
             self.connect("drag-data-get", self._get_drag_data)
-           
-        # reset config 
-        self._on_pos_changed()
         
         # Signals
         self._config.notify_add("pos", self._on_pos_changed)
         self.connect("row-activated", self._on_row_activated)
     
+    def restore(self):
+        self._on_pos_changed()
+    
     def _recieve_drag_data(self, tv, ctxt, x, y, selection, *args):
         print selection.get_uris()
     
